package
Version:
v0.0.0-...-96209b5
Opens a new window with list of versions in this module.
Published: Nov 7, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Interface[T any] interface {
Peek() T
Pop() T
Push(T)
Size() int
}
type Queue[T any] struct {
}
func (q *Queue[T]) Peek() T
func (q *Queue[T]) Pop() T
func (q *Queue[T]) Push(t T)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.