package
Version:
v0.0.0-...-96209b5
Opens a new window with list of versions in this module.
Published: Nov 7, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Map[T any, R any](slice []T, f func(int, T) R) []R
func Zip[T1 any, T2 any](s1 []T1, s2 []T2, f func(T1, T2))
Source Files
¶
Click to show internal directories.
Click to hide internal directories.